Fix rsync exit handling in create mode.
[dss.git] / snap.h
diff --git a/snap.h b/snap.h
index 7ac951fc313adb9f0867bc90463d4773f215adb9..626ecad003a52a1a465ea6f7f2e11f960a97df3c 100644 (file)
--- a/snap.h
+++ b/snap.h
@@ -1,46 +1,32 @@
 /*
- * Copyright (C) 2008 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2008-2010 Andre Noll <maan@tuebingen.mpg.de>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
-/** The state of snapshot creation. */
-enum {
-       /** We are ready to take the next snapshot. */
-       SCS_READY,
-       /** The pre-creation hook has been started. */
-       SCS_PRE_HOOK_RUNNING,
-       /** The pre-creation hook exited successfully. */
-       SCS_PRE_HOOK_SUCCESS,
-       /** The rsync process is running. */
-       SCS_RSYNC_RUNNING,
-       /** The rsync process exited successfully. */
-       SCS_RSYNC_SUCCESS,
-       /** The rsync process needs to be restarted. */
-       SCS_RSYNC_NEEDS_RESTART,
-       /** The post-create hook has been started. */
-       SCS_POST_HOOK_RUNNING,
-};
 
-/** The state of snapshot removal. */
-enum {
-       /** No snapshot is currently being removed. */
-       SRS_READY,
-       /** The pre-removal hook has been started. */
-       SRS_PRE_HOOK_RUNNING,
-       /** The pre-remove hook failed, we're waiting to execute it again. */
-       SRS_PRE_HOOK_FAILURE,
-       /** The rm command is currently executing. */
-       SRS_RM_RUNNING,
-       /** The post-remove hook ist running. */
-       SRS_POST_HOOK_RUNNING,
-};
+/** The possible states for snapshot creation/removal. */
+#define HOOK_STATUS_ARRAY \
+       HSA_ITEM(HS_READY, "ready for action"), \
+       HSA_ITEM(HS_PRE_RUNNING, "pre-hook running"), \
+       HSA_ITEM(HS_PRE_SUCCESS, "pre-hook completed successfully"), \
+       HSA_ITEM(HS_RUNNING, "in progress"), \
+       HSA_ITEM(HS_SUCCESS, "process terminated successfully"), \
+       HSA_ITEM(HS_NEEDS_RESTART, "restart needed"), \
+       HSA_ITEM(HS_POST_RUNNING, "post-hook running")
+
+
+#define HSA_ITEM(x, y) x
+enum hook_status {HOOK_STATUS_ARRAY};
+#undef HSA_ITEM
+#define HSA_ITEM(x, y) y
+
 
 /**
  * The status of a snapshot.
  *
  * The snapshot directories come in four different flavours, depending
* on how the two staus flags are set. Examples:
  *
  * Complete, not being deleted: 1204565370-1204565371.Sun_Mar_02_2008_14_33-Sun_Mar_02_2008_14_43.
  * Complete, being deleted: 1204565370-1204565371.being_deleted.
@@ -51,7 +37,7 @@ enum snapshot_status_flags {
        /** The rsync process terminated successfully. */
        SS_COMPLETE = 1,
        /** The rm process is running to remove this snapshot. */
-       SS_BEING_DELETED = 2,
+       SS_BEING_DELETED = 2
 };
 
 /** Describes one snapshot. */
@@ -62,7 +48,7 @@ struct snapshot {
        int64_t creation_time;
        /**
         * Seconds after the epoch when creation of this snapshot completed.
* Only meaningful if the SS_COMPLTE bit is set.
         */
        int64_t completion_time;
        /** See \ref snapshot_status_flags. */
@@ -102,13 +88,14 @@ __malloc char *incomplete_name(int64_t start);
 __malloc char *being_deleted_name(struct snapshot *s);
 int complete_name(int64_t start, int64_t end, char **result);
 __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl);
+int num_complete_snapshots(struct snapshot_list *sl);
 
 /**
* Get the oldest snapshot in a snapshot list.
  */
-_static_inline_ struct snapshot *get_oldest_snapshot(struct snapshot_list *sl)
+_static_inline_ struct snapshot *get_newest_snapshot(struct snapshot_list *sl)
 {
        if (!sl->num_snapshots)
                return NULL;
-       return sl->snapshots[0];
+       return sl->snapshots[sl->num_snapshots - 1];
 }
@@ -1,46 +1,32 @@
  *
  * The snapshot directories come in four different flavours, depending
- * on how the two staus flags are set. Examples:
+ * on how the two status flags are set. Examples:
  *
  * Complete, not being deleted: 1204565370-1204565371.Sun_Mar_02_2008_14_33-Sun_Mar_02_2008_14_43.
@@ -62,7 +48,7 @@ struct snapshot {
        /**
         * Seconds after the epoch when creation of this snapshot completed.
-        * Only meaningful if the SS_COMPLTE bit is set.
+        * Only meaningful if the SS_COMPLETE bit is set.
         */
        int64_t completion_time;
@@ -102,13 +88,14 @@ __malloc char *incomplete_name(int64_t start);
 
 /**
- * Get the oldest snapshot in a snapshot list.
+ * Get the newest snapshot in a snapshot list.
  */